@@ -5,6 +5,7 @@ import typer
 
 import cpdf.cat
 import cpdf.extract_images
+import cpdf.metadata
 import cpdf.up2
 
 
@@ -23,7 +24,7 @@ entry_point = typer.Typer(
 @entry_point.callback()  # type: ignore[misc]
 def common(
     ctx: typer.Context,
-    version: bool = typer.Option(None, "--version", callback=version_callback),
+    version: bool = typer.Option(None, "--version", callback=version_callback),  # noqa
 ) -> None:
     pass
 
@@ -41,13 +42,32 @@ def up2(pdf: Path, out: Path) -> None:
 @entry_point.command(name="cat")  # type: ignore[misc]
 def cat(
     filename: Path,
-    output: Path = typer.Option(..., "-o", "--output"),
-    fn_pgrgs: List[str] = typer.Argument(..., help="filenames and/or page ranges"),
-    verbose: bool = typer.Option(False, help="show page ranges as they are being read"),
+    output: Path = typer.Option(..., "-o", "--output"),  # noqa
+    fn_pgrgs: List[str] = typer.Argument(  # noqa
+        ..., help="filenames and/or page ranges"
+    ),
+    verbose: bool = typer.Option(  # noqa
+        False, help="show page ranges as they are being read"
+    ),
 ) -> None:
     cpdf.cat.main(filename, fn_pgrgs, output, verbose)
 
 
+@entry_point.command(name="meta")  # type: ignore[misc]
+def metadata(
+    pdf: Path,
+    output: cpdf.metadata.OutputOptions = typer.Option(  # noqa
+        ...,
+        "--output",
+        "-o",
+        help="output format",
+        show_default=True,
+    ),
+) -> None:
+    cpdf.metadata.main(pdf, output)
+
+
 up2.__doc__ = cpdf.up2.__doc__
 extract_images.__doc__ = cpdf.extract_images.__doc__
 cat.__doc__ = cpdf.cat.__doc__
+metadata.__doc__ = cpdf.metadata.__doc__
